==> html2pdf-3.0.4-sources.jar: com/itextpdf/html2pdf/css/apply/util/FloatApplierUtil.java <==
/*
    This file is part of the iText (R) project.
    Copyright (c) 1998-2021 iText Group NV
    Authors: Bruno Lowagie, Paulo Soares, et al.
    
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU Affero General Public License version 3
    as published by the Free Software Foundation with the addition of the
    following permission added to Section 15 as permitted in Section 7(a):
    FOR ANY PART OF THE COVERED WORK IN WHICH THE COPYRIGHT IS OWNED BY
    ITEXT GROUP. ITEXT GROUP DISCLAIMS THE WARRANTY OF NON INFRINGEMENT
    OF THIRD PARTY RIGHTS
    
    This program is distributed in the hope that it will be useful, but
    WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
    or FITNESS FOR A PARTICULAR PURPOSE.
    See the GNU Affero General Public License for more details.
    You should have received a copy of the GNU Affero General Public License
    along with this program; if not, see http://www.gnu.org/licenses or write to
    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
    Boston, MA, 02110-1301 USA, or download the license from the following URL:
    http://itextpdf.com/terms-of-use/
    
    The interactive user interfaces in modified source and object code versions
    of this program must display Appropriate Legal Notices, as required under
    Section 5 of the GNU Affero General Public License.
    
    In accordance with Section 7(b) of the GNU Affero General Public License,
    a covered work must retain the producer line in every PDF that is created
    or manipulated using iText.
    
    You can be released from the requirements of the license by purchasing
    a commercial license. Buying such a license is mandatory as soon as you
    develop commercial activities involving the iText software without
    disclosing the source code of your own applications.
    These activities include: offering paid services to customers as an ASP,
    serving PDFs on the fly in a web application, shipping iText with a closed
    source product.
    
    For more information, please contact iText Software Corp. at this
    address: sales@itextpdf.com
 */
package com.itextpdf.html2pdf.css.apply.util;

import com.itextpdf.html2pdf.attach.ProcessorContext;
import com.itextpdf.html2pdf.css.CssConstants;
import com.itextpdf.layout.IPropertyContainer;
import com.itextpdf.layout.property.ClearPropertyValue;
import com.itextpdf.layout.property.FloatPropertyValue;
import com.itextpdf.layout.property.Property;

import java.util.Map;

/**
 * Utilities class to apply float values to elements.
 */
public class FloatApplierUtil {

    /**
     * Creates a new {@link FloatApplierUtil} instance.
     */
    private FloatApplierUtil() {
    }

    /**
     * Applies a float value (left, right, or both) to an element.
     *
     * @param cssProps the CSS properties
     * @param context the processor context
     * @param element the element
     */
    public static void applyFloating(Map<String, String> cssProps, ProcessorContext context, IPropertyContainer element) {
        String floatValue = cssProps.get(CssConstants.FLOAT);
        if (floatValue != null) {
            if (CssConstants.LEFT.equals(floatValue)) {
                element.setProperty(Property.FLOAT, FloatPropertyValue.LEFT);

            } else if (CssConstants.RIGHT.equals(floatValue)) {
                element.setProperty(Property.FLOAT, FloatPropertyValue.RIGHT);
            }
        }

        String clearValue = cssProps.get(CssConstants.CLEAR);
        if (clearValue != null) {
            if(CssConstants.LEFT.equals(clearValue)) {
                element.setProperty(Property.CLEAR, ClearPropertyValue.LEFT);
            } else if (CssConstants.RIGHT.equals(clearValue)) {
                element.setProperty(Property.CLEAR, ClearPropertyValue.RIGHT);
            } else if (CssConstants.BOTH.equals(clearValue)) {
                element.setProperty(Property.CLEAR, ClearPropertyValue.BOTH);
            }
        }
    }
}

==> html2pdf-4.0.1-sources.jar: com/itextpdf/html2pdf/css/apply/util/FloatApplierUtil.java <==
/*
    This file is part of the iText (R) project.
    Copyright (c) 1998-2021 iText Group NV
    Authors: Bruno Lowagie, Paulo Soares, et al.
    
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU Affero General Public License version 3
    as published by the Free Software Foundation with the addition of the
    following permission added to Section 15 as permitted in Section 7(a):
    FOR ANY PART OF THE COVERED WORK IN WHICH THE COPYRIGHT IS OWNED BY
    ITEXT GROUP. ITEXT GROUP DISCLAIMS THE WARRANTY OF NON INFRINGEMENT
    OF THIRD PARTY RIGHTS
    
    This program is distributed in the hope that it will be useful, but
    WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
    or FITNESS FOR A PARTICULAR PURPOSE.
    See the GNU Affero General Public License for more details.
    You should have received a copy of the GNU Affero General Public License
    along with this program; if not, see http://www.gnu.org/licenses or write to
    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
    Boston, MA, 02110-1301 USA, or download the license from the following URL:
    http://itextpdf.com/terms-of-use/
    
    The interactive user interfaces in modified source and object code versions
    of this program must display Appropriate Legal Notices, as required under
    Section 5 of the GNU Affero General Public License.
    
    In accordance with Section 7(b) of the GNU Affero General Public License,
    a covered work must retain the producer line in every PDF that is created
    or manipulated using iText.
    
    You can be released from the requirements of the license by purchasing
    a commercial license. Buying such a license is mandatory as soon as you
    develop commercial activities involving the iText software without
    disclosing the source code of your own applications.
    These activities include: offering paid services to customers as an ASP,
    serving PDFs on the fly in a web application, shipping iText with a closed
    source product.
    
    For more information, please contact iText Software Corp. at this
    address: sales@itextpdf.com
 */
package com.itextpdf.html2pdf.css.apply.util;

import com.itextpdf.html2pdf.attach.ProcessorContext;
import com.itextpdf.html2pdf.css.CssConstants;
import com.itextpdf.layout.IPropertyContainer;
import com.itextpdf.layout.properties.ClearPropertyValue;
import com.itextpdf.layout.properties.FloatPropertyValue;
import com.itextpdf.layout.properties.Property;

import java.util.Map;

/**
 * Utilities class to apply float values to elements.
 */
public class FloatApplierUtil {

    /**
     * Creates a new {@link FloatApplierUtil} instance.
     */
    private FloatApplierUtil() {
    }

    /**
     * Applies a float value (left, right, or both) to an element.
     *
     * @param cssProps the CSS properties
     * @param context the processor context
     * @param element the element
     */
    public static void applyFloating(Map<String, String> cssProps, ProcessorContext context, IPropertyContainer element) {
        String floatValue = cssProps.get(CssConstants.FLOAT);
        if (floatValue != null) {
            if (CssConstants.LEFT.equals(floatValue)) {
                element.setProperty(Property.FLOAT, FloatPropertyValue.LEFT);

            } else if (CssConstants.RIGHT.equals(floatValue)) {
                element.setProperty(Property.FLOAT, FloatPropertyValue.RIGHT);
            }
        }

        String clearValue = cssProps.get(CssConstants.CLEAR);
        if (clearValue != null) {
            if(CssConstants.LEFT.equals(clearValue)) {
                element.setProperty(Property.CLEAR, ClearPropertyValue.LEFT);
            } else if (CssConstants.RIGHT.equals(clearValue)) {
                element.setProperty(Property.CLEAR, ClearPropertyValue.RIGHT);
            } else if (CssConstants.BOTH.equals(clearValue)) {
                element.setProperty(Property.CLEAR, ClearPropertyValue.BOTH);
            }
        }
    }
}
